@@ -549,9 +549,10 @@ class VariableClAutopartitionSet(Variable):
                 ("off", _("Use the current partitions"))]
 
     def get(self):
-        if self.Get('os_root_type_ext') in (RootType.LiveCD, RootType.LiveFlash,
-                                            RootType.IsoScanFlash,
-                                            RootType.NetBoot):
+        if self.Get('os_root_type_ext') in (RootType.Value.LiveCD,
+                                            RootType.Value.LiveFlash,
+                                            RootType.Value.IsoScanFlash,
+                                            RootType.Value.NetBoot):
             return "on"
         else:
             return "off"
